/* Generated by ./src/xlat/gen.sh from ./src/xlat/ptp_perout_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat ptp_perout_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data ptp_perout_flags_xdata[] = {
 XLAT(PTP_PEROUT_ONE_SHOT),
 #define XLAT_VAL_0 ((unsigned) (PTP_PEROUT_ONE_SHOT))
 #define XLAT_STR_0 STRINGIFY(PTP_PEROUT_ONE_SHOT)
 XLAT(PTP_PEROUT_DUTY_CYCLE),
 #define XLAT_VAL_1 ((unsigned) (PTP_PEROUT_DUTY_CYCLE))
 #define XLAT_STR_1 STRINGIFY(PTP_PEROUT_DUTY_CYCLE)
 XLAT(PTP_PEROUT_PHASE),
 #define XLAT_VAL_2 ((unsigned) (PTP_PEROUT_PHASE))
 #define XLAT_STR_2 STRINGIFY(PTP_PEROUT_PHASE)
};
static
const struct xlat ptp_perout_flags[1] = { {
 .data = ptp_perout_flags_xdata,
 .size = ARRAY_SIZE(ptp_perout_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
