/* Generated by ./src/xlat/gen.sh from ./src/xlat/ubi_volume_types.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat ubi_volume_types in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data ubi_volume_types_xdata[] = {
 XLAT(UBI_DYNAMIC_VOLUME),
 #define XLAT_VAL_0 ((unsigned) (UBI_DYNAMIC_VOLUME))
 #define XLAT_STR_0 STRINGIFY(UBI_DYNAMIC_VOLUME)
 XLAT(UBI_STATIC_VOLUME),
 #define XLAT_VAL_1 ((unsigned) (UBI_STATIC_VOLUME))
 #define XLAT_STR_1 STRINGIFY(UBI_STATIC_VOLUME)
};
static
const struct xlat ubi_volume_types[1] = { {
 .data = ubi_volume_types_xdata,
 .size = ARRAY_SIZE(ubi_volume_types_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
